==> pytracksim-1.0.1-py3-none-any.whl: tracksim/vehicle_models.py <==

GenericVehicle = {'Model name' : 'GenericVehicle',
                  'Reference' : None,
                  'Description' : 'Generic structure of a vehicle model.',
                  'Number of wheels' : None,
                  'Brake drag [N]' : None,
                  'Drag coefficient' : None,
                  'Frontal area [m2]' : None,
                  'Mass [kg]' : None,
                  'Payload [kg]' : None,
                  'Overhead power [W]' : None,
                  'Inverter efficiency' : None,
                  'Fractional regen torque limit' : None,
                  'Gear ratio' : None,
                  'Gear inertia [kg/m2]' : None,
                  'Gear efficiency' : None,
                  'Wheel radius [m]' : None,
                  'Wheel inertia [kg/m2]' : None,
                  'Rolling coefficient' : None,
                  'Max motor torque [Nm]' : None,
                  'Rated RPM [RPM]' : None,
                  'Max RPM [RPM]' : None,
                  'Motor efficiency' : None,
                  'Motor inertia [kg/m2]' : None}

ChevyVolt = {'Model name' : 'Chevy Volt',
             'Reference' : 'G. L. Plett, Battery Management Systems, Volume 2: Equivalent Circuit Methods. in Artech House Power engineering series. Boston: Artech house, 2016.',
             'Description' : 'Model of a Chevy Volt with parameters as described in Plett, 2016.',
             'Number of wheels' : 4,
             'Brake drag [N]' : 0,
             'Drag coefficient' : 0.22,
             'Frontal area [m2]' : 1.84,
             'Mass [kg]' : 1425,
             'Payload [kg]' : 75,
             'Overhead power [W]' : 200,
             'Inverter efficiency' : 0.94,
             'Fractional regen torque limit' : 0.9,
             'Gear Ratio' : 0.05,
             'Gear inertia [kg/m2]' : 0.05,
             'Gear efficiency' : 0.97,
             'Wheel radius [m]' : 0.35,
             'Wheel inertia [kg/m2]' : 8,
             'Rolling coefficient' : 0.0111,
             'Max motor torque [Nm]' : 275,
             'Rated RPM [RPM]' : 4000,
             'Max RPM [RPM]' : 12000,
             'Motor efficiency' : 0.95,
             'Motor inertia [kg/m2]' : 0.2}

ChevyVoltTuned = {'Model name' : 'Chevy Volt',
                  'Reference' : 'G. L. Plett, Battery Management Systems, Volume 2: Equivalent Circuit Methods. in Artech House Power engineering series. Boston: Artech house, 2016.',
                  'Description' : 'A modified version of ChevyVolt with higher maximum motor torque and RPM.',
                  'Number of wheels' : 4,
                  'Brake drag [N]' : 0,
                  'Drag coefficient' : 0.22,
                  'Frontal area [m2]' : 1.84,
                  'Mass [kg]' : 1425,
                  'Payload [kg]' : 75,
                  'Overhead power [W]' : 200,
                  'Inverter efficiency' : 0.94,
                  'Fractional regen torque limit' : 0.9,
                  'Gear ratio' : 12,
                  'Gear inertia [kg/m2]' : 0.05,
                  'Gear efficiency' : 0.97,
                  'Wheel radius [m]' : 0.35,
                  'Wheel inertia [kg/m2]' : 8,
                  'Rolling coefficient' : 0.0111,
                  'Max motor torque [Nm]' : 1420,
                  'Rated RPM [RPM]' : 4000,
                  'Max RPM [RPM]' : 23000,
                  'Motor efficiency' : 0.95,
                  'Motor inertia [kg/m2]' : 0.2}

==> pytracksim-1.1.1-py3-none-any.whl: tracksim/vehicle_models.py <==

GenericVehicle = {'Model name' : 'GenericVehicle',
                  'Reference' : None,
                  'Description' : 'Generic structure of a vehicle model.',
                  'Number of wheels' : None,
                  'Brake drag [N]' : None,
                  'Drag coefficient' : None,
                  'Frontal area [m2]' : None,
                  'Mass [kg]' : None,
                  'Payload [kg]' : None,
                  'Overhead power [W]' : None,
                  'Inverter efficiency' : None,
                  'Fractional regen torque limit' : None,
                  'Gear ratio' : None,
                  'Gear inertia [kg/m2]' : None,
                  'Gear efficiency' : None,
                  'Wheel radius [m]' : None,
                  'Wheel inertia [kg/m2]' : None,
                  'Rolling coefficient' : None,
                  'Max motor torque [Nm]' : None,
                  'Rated RPM [RPM]' : None,
                  'Max RPM [RPM]' : None,
                  'Motor efficiency' : None,
                  'Motor inertia [kg/m2]' : None}

ChevyVolt = {'Model name' : 'ChevyVolt',
             'Reference' : 'G. L. Plett, Battery Management Systems, Volume 2: Equivalent Circuit Methods. in Artech House Power engineering series. Boston: Artech house, 2016.',
             'Description' : 'Model of a Chevy Volt with parameters as described in Plett, 2016.',
             'Number of wheels' : 4,
             'Brake drag [N]' : 0,
             'Drag coefficient' : 0.22,
             'Frontal area [m2]' : 1.84,
             'Mass [kg]' : 1425,
             'Payload [kg]' : 75,
             'Overhead power [W]' : 200,
             'Inverter efficiency' : 0.94,
             'Fractional regen torque limit' : 0.9,
             'Gear Ratio' : 0.05,
             'Gear inertia [kg/m2]' : 0.05,
             'Gear efficiency' : 0.97,
             'Wheel radius [m]' : 0.35,
             'Wheel inertia [kg/m2]' : 8,
             'Rolling coefficient' : 0.0111,
             'Max motor torque [Nm]' : 275,
             'Rated RPM [RPM]' : 4000,
             'Max RPM [RPM]' : 12000,
             'Motor efficiency' : 0.95,
             'Motor inertia [kg/m2]' : 0.2}

ChevyVoltTuned = {'Model name' : 'ChevyVoltTuned',
                  'Reference' : 'G. L. Plett, Battery Management Systems, Volume 2: Equivalent Circuit Methods. in Artech House Power engineering series. Boston: Artech house, 2016.',
                  'Description' : 'A modified version of ChevyVolt with higher maximum motor torque and RPM.',
                  'Number of wheels' : 4,
                  'Brake drag [N]' : 0,
                  'Drag coefficient' : 0.22,
                  'Frontal area [m2]' : 1.84,
                  'Mass [kg]' : 1425,
                  'Payload [kg]' : 75,
                  'Overhead power [W]' : 200,
                  'Inverter efficiency' : 0.94,
                  'Fractional regen torque limit' : 0.9,
                  'Gear ratio' : 12,
                  'Gear inertia [kg/m2]' : 0.05,
                  'Gear efficiency' : 0.97,
                  'Wheel radius [m]' : 0.35,
                  'Wheel inertia [kg/m2]' : 8,
                  'Rolling coefficient' : 0.0111,
                  'Max motor torque [Nm]' : 1420,
                  'Rated RPM [RPM]' : 4000,
                  'Max RPM [RPM]' : 23000,
                  'Motor efficiency' : 0.95,
                  'Motor inertia [kg/m2]' : 0.2}
